"use client";

import arrow_right from "@/assets/vector1.svg";
import { Rating } from "@mui/material";
import Image from "next/image";
import React, { useRef } from "react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import { Pagination } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";

const ButtomSlider = ({ data }) => {
  const swiperRef = useRef(null);

  const handlePrevSlide = () => {
    if (swiperRef.current && swiperRef.current.swiper) {
      swiperRef.current.swiper.slidePrev();
    }
  };

  const handleNextSlide = () => {
    if (swiperRef.current && swiperRef.current.swiper) {
      swiperRef.current.swiper.slideNext();
    }
  };

  const truncateTitle = (title) => {
    const words = title.split(" ");
    if (words.length > 2) {
      return `${words.slice(0, 2).join(" ")}...`;
    }
    return title;
  };

  return (
    <div className="">
      <div className="flex items-center relative">
        <div
          onClick={handlePrevSlide}
          className="btn-gradient px-2 py-1 rounded cursor-pointer absolute top-[50%] -left-3 sm:-left-12 z-40"
        >
          <Image
            src={arrow_right}
            alt="previous"
            className="transform rotate-180"
          />
        </div>
        <Swiper
          spaceBetween={20}
          slidesPerView={4}
          hashNavigation={{
            watchState: true,
          }}
          breakpoints={{
            320: {
              slidesPerView: 1,
              spaceBetween: 10,
            },
            640: {
              slidesPerView: 2,
              spaceBetween: 20,
            },
            768: {
              slidesPerView: 3,
              spaceBetween: 20,
            },
            1024: {
              slidesPerView: 4,
              spaceBetween: 20,
            },
          }}
          modules={[Pagination]}
          ref={swiperRef}
          className="h-[380px] !pb-[40px] w-full"
        >
          {data.map((property, index) => (
            <SwiperSlide key={index} className="mt-[32px]">
              <div className="rounded-lg h-auto shadow mx-1 flex flex-col justify-between">
                <div className="relative w-[300px] h-[250px]">
                  <Image
                    src={
                      property.thumbnailImg?.images[0]?.url ||
                      "/product/rectangle-105@2x.png"
                    }
                    alt={`slide-${index}`}
                    className="object-cover rounded-[12px]"
                    width={300}
                    height={300}
                  />
                </div>
                <div className="p-3">
                  <h2 className="text-xl capitalize font-medium text-blue">
                    {truncateTitle(property.title)}
                  </h2>
                  <div className="flex flex-row justify-center items-center space-x-3">
                    <Rating
                      className="text-xs"
                      name="half-rating-read"
                      defaultValue={property.totalrating || 2.5}
                      precision={0.5}
                      readOnly
                    />
                    <span className="text-xs underline">
                      {property?.ratings?.length || 0} Reviews
                    </span>
                  </div>
                  <div className="pt-2">
                    <span className="font-medium text-xl">
                      ${property.price || "N/A"}
                    </span>
                  </div>
                </div>
              </div>
            </SwiperSlide>
          ))}
        </Swiper>
        <div
          onClick={handleNextSlide}
          className="btn-gradient px-2 py-1 rounded cursor-pointer absolute top-[50%] -right-3 sm:-right-12 z-40"
        >
          <Image src={arrow_right} alt="next" />
        </div>
      </div>
    </div>
  );
};

export default ButtomSlider;
